@@ -17,7 +17,12 @@ import aws_solutions_constructs.aws_lambda_dynamodb._jsii
 import aws_solutions_constructs.core._jsii
 import constructs._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-solutions-constructs/aws-iot-lambda-dynamodb", "1.47.0", __name__[0:-6], "aws-iot-lambda-dynamodb@1.47.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "@aws-solutions-constructs/aws-iot-lambda-dynamodb",
+    "1.51.0",
+    __name__[0:-6],
+    "aws-iot-lambda-dynamodb@1.51.0.jsii.tgz",
+)
 
 __all__ = [
     "__jsii_assembly__",
